#!/bin/bash

# This code block is a hack to enable execution of demo scripts without
# global installation of bash-base. Do not use in your production scripts.
BBLIBFILE=base.bash
for bbloc in bash-base.bash ../libexec/bash-base.bash \
    /usr/libexec/bash-base.bash
do
    if [ -f "$bbloc" ]
    then
	BBLIBFILE="$bbloc"
	break
    fi
done

# source bash base library
source "$BBLIBFILE" || {
    echo "$0: fatal error: failed to source bash-base.bash" >&2
    exit 1
}

function cleanup() {
    log "cleanup called"
}

# replace the contents with your code
function main() {
    echo "this function is an example"
    echo "(un)comment lines below to test what happens on various failures"

    echo "main was called with args: '$*'"

    # make sure cleanup() is called at script exit
    bb_register_exit_hook mycleanuphook cleanup

    ## fatal error manually stops execution whereever called
    ## still you will get stack trace so you know where it happened
    fatal "kenny?"

    ## access to unset variables will trigger an error that is not catched
    ## by the ERR trap but by the EXIT trap. As a result the last line
    ## number of the stack trace will be incorrect (always 1)
    echo "$NoSuchVariableDefined"

    ## a command that fails: will trigger an error inside of main
    false

    ## this will sucessfully end function main, but since the return value
    ## is != 0 it will trigger an error where main was called
    return 123
}

# just call a function, never run code directly
main "$@"

# always use bb_quit to quit, it cares about traps and hooks
bb_quit
